.. _toolkits-index:

.. _toolkits:

########
Toolkits
########



Toolkits are collections of application-specific functions that extend
Matplotlib.


.. _toolkit_mplot3d:

mplot3d
=======

:mod:`mpl_toolkits.mplot3d` provides some basic 3D
plotting (scatter, surf, line, mesh) tools.  Not the fastest or most feature
complete 3D library out there, but it ships with Matplotlib and thus may be a
lighter weight solution for some use cases. Check out the
:ref:`mplot3d tutorial <sphx_glr_tutorials_toolkits_mplot3d.py>` for more
information.

.. figure:: ../gallery/mplot3d/images/sphx_glr_contourf3d_2_001.png
   :target: ../gallery/mplot3d/contourf3d_2.html
   :align: center
   :scale: 50

   Contourf3d 2

.. toctree::
    :maxdepth: 2

    mplot3d/index.rst
    mplot3d/faq.rst

Links
-----
* mpl3d API: :ref:`toolkit_mplot3d-api`

.. _toolkit_axes_grid1:

axes_grid1
==========

The :mod:`mpl_toolkits.axes_grid1` toolkit is a
collection of helper classes for displaying multiple axes in Matplotlib.

.. image:: /_static/demo_axes_grid.png

.. toctree::
    :maxdepth: 2

    axes_grid1/index.rst


.. _toolkit_axisartist:

axisartist
==========

The :mod:`mpl_toolkits.axisartist` toolkit contains
a custom Axes class that is meant to support curvilinear grids.

.. toctree::
    :maxdepth: 2

    axisartist/index.rst


API
---
* Axes Grid and Axis Artist API: :ref:`axes_grid-api-index`

